# Copyright Spack Project Developers. See COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack_repo.builtin.build_systems.python import PythonPackage

from spack.package import *


class PyPreCommit(PythonPackage):
    """A framework for managing and maintaining multi-language pre-commit
    hooks."""

    homepage = "https://github.com/pre-commit/pre-commit"
    pypi = "pre_commit/pre_commit-1.20.0.tar.gz"

    license("MIT")

    version("4.2.0", sha256="601283b9757afd87d40c4c4a9b2b5de9637a8ea02eaff7adc2d0fb4e04841146")
    version("4.1.0", sha256="ae3f018575a588e30dfddfab9a05448bfbd6b73d78709617b5a2b853549716d4")
    version("4.0.1", sha256="80905ac375958c0444c65e9cebebd948b3cdb518f335a091a670a89d652139d2")
    version("3.8.0", sha256="8bb6494d4a20423842e198980c9ecf9f96607a07ea29549e180eef9ae80fe7af")
    version("3.7.1", sha256="8ca3ad567bc78a4972a3f1a477e94a79d4597e8140a6e0b651c5e33899c3654a")
    version("3.6.2", sha256="c3ef34f463045c88658c5b99f38c1e297abdcc0ff13f98d3370055fbbfabc67e")
    version("3.6.0", sha256="d30bad9abf165f7785c15a21a1f46da7d0677cb00ee7ff4c579fd38922efe15d")
    version("3.5.0", sha256="5804465c675b659b0862f07907f96295d490822a450c4c40e747d0b1c6ebcb32")
    version("3.3.3", sha256="a2256f489cd913d575c145132ae196fe335da32d91a8294b7afe6622335dd023")
    version("2.20.0", sha256="a978dac7bc9ec0bcee55c18a277d553b0f419d259dadb4b9418ff2d00eb43959")
    version("2.17.0", sha256="c1a8040ff15ad3d648c70cc3e55b93e4d2d5b687320955505587fd79bbaed06a")
    version("2.10.1", sha256="399baf78f13f4de82a29b649afd74bef2c4e28eb4f021661fc7f29246e8c7a3a")
    version("1.20.0", sha256="9f152687127ec90642a2cc3e4d9e1e6240c4eb153615cb02aa1ad41d331cbb6e")

    depends_on("python@3.9:", when="@3.6:", type=("build", "run"))
    depends_on("python@3.8:", when="@3:", type=("build", "run"))
    depends_on("python@3.7:", when="@2.20.0:", type=("build", "run"))
    depends_on("python@3.6.1:", when="@2.1.0:", type=("build", "run"))
    depends_on("py-setuptools", type="build")

    depends_on("py-cfgv@2:", type=("build", "run"))
    depends_on("py-identify@1:", type=("build", "run"))
    depends_on("py-nodeenv@0.11.1:", type=("build", "run"))
    depends_on("py-pyyaml@5.1:", when="@2.1:", type=("build", "run"))
    depends_on("py-pyyaml", type=("build", "run"))
    depends_on("py-virtualenv@20.10:", when="@2.21:", type=("build", "run"))
    depends_on("py-virtualenv@20.0.8:", when="@2.4:", type=("build", "run"))
    depends_on("py-virtualenv@15.2:", type=("build", "run"))

    # Historical dependencies
    depends_on("py-toml", when="@:2.20", type=("build", "run"))
    depends_on("py-aspy-yaml", when="@1", type=("build", "run"))
    depends_on("py-six", when="@1", type=("build", "run"))
    depends_on("py-importlib-metadata", when="@:2 ^python@:3.7", type=("build", "run"))
